@@ -12,22 +12,22 @@ SORT_OPTIONS = SortedDict((
     ('accel_60', _('Trending: %(minutes)d minutes' % {'minutes': 60})),
 ))
 SORT_CLAUSES = {
-    'priority': 'score',
-    'date': 'EXTRACT(EPOCH FROM last_seen)',
-    'new': 'EXTRACT(EPOCH FROM first_seen)',
-    'freq': 'times_seen',
-    'tottime': 'time_spent_total',
-    'avgtime': '(time_spent_total / time_spent_count)',
+    'priority': 'sentry_groupedmessage.score',
+    'date': 'EXTRACT(EPOCH FROM sentry_groupedmessage.last_seen)',
+    'new': 'EXTRACT(EPOCH FROM sentry_groupedmessage.first_seen)',
+    'freq': 'sentry_groupedmessage.times_seen',
+    'tottime': 'sentry_groupedmessage.time_spent_total',
+    'avgtime': '(sentry_groupedmessage.time_spent_total / sentry_groupedmessage.time_spent_count)',
 }
 SQLITE_SORT_CLAUSES = SORT_CLAUSES.copy()
 SQLITE_SORT_CLAUSES.update({
-    'date': 'last_seen',
-    'new': 'first_seen',
+    'date': 'sentry_groupedmessage.last_seen',
+    'new': 'sentry_groupedmessage.first_seen',
 })
 MYSQL_SORT_CLAUSES = SORT_CLAUSES.copy()
 MYSQL_SORT_CLAUSES.update({
-    'date': 'UNIX_TIMESTAMP(last_seen)',
-    'new': 'UNIX_TIMESTAMP(first_seen)',
+    'date': 'UNIX_TIMESTAMP(sentry_groupedmessage.last_seen)',
+    'new': 'UNIX_TIMESTAMP(sentry_groupedmessage.first_seen)',
 })
 SEARCH_SORT_OPTIONS = SortedDict((
     ('score', _('Score')),
