@@ -577,16 +577,8 @@ class GroupManager(BaseManager, ChartMixin):
             'date': normalized_datetime,
         })
 
-        http = event.interfaces.get('sentry.interfaces.Http')
-        if http:
-            url = http.url
-        else:
-            url = None
-
+        # TODO: should we move this into a TagPlugin?
         for key, value in (
-                ('server_name', event.server_name),
-                ('site', event.site),
-                ('url', url),
                 ('logger', event.logger),
             ):
             if not value:
