@@ -386,6 +386,9 @@ class Group(MessageBase):
     times_seen = models.PositiveIntegerField(default=1, db_index=True)
     last_seen = models.DateTimeField(default=datetime.now, db_index=True)
     first_seen = models.DateTimeField(default=datetime.now, db_index=True)
+    resolved_at = models.DateTimeField(null=True, db_index=True)
+    # active_at should be the same as first_seen by default
+    active_at = models.DateTimeField(null=True, db_index=True)
     time_spent_total = models.FloatField(default=0)
     time_spent_count = models.IntegerField(default=0)
     score = models.IntegerField(default=0)
@@ -405,6 +408,15 @@ class Group(MessageBase):
     def __unicode__(self):
         return "(%s) %s" % (self.times_seen, self.error())
 
+    def save(self, *args, **kwargs):
+        if not self.last_seen:
+            self.last_seen = datetime.now()
+        if not self.first_seen:
+            self.first_seen = self.last_seen
+        if not self.active_at:
+            self.active_at = self.first_seen
+        super(Group, self).save(*args, **kwargs)
+
     def get_absolute_url(self):
         if self.project_id:
             return reverse('sentry-group', kwargs={'group_id': self.pk, 'project_id': self.project.slug})
